import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Tag, Pagination, Modal, Radio, DatePicker, notification } from 'antd';
import router from 'umi/router';
import moment from 'moment';
import AuthButton from '@/components/AuthButton';
import withActions from '@/components/ActionList';
import EditIcon from '@/components/EditIcon';
import Navigate from '@/components/Navigate';
import styles from '../../style/GoodsList.less';
import BuildSelect from '@/components/SelectButton/BuildSelect'
import QrcodeType from '@/components/SelectButton/QrcodeType'
import ChannelSelect from '@/components/SelectButton/channelSelect'
import apis from '../../../services/apis';
import request from '../../../utils/request';

// import RaiseHelpDoc from '../edit/components/RaiseHelpDoc';

const { RangePicker } = DatePicker

const qrcodelist = props => {
    const { id, name, customerNum } = props.location.query
    const [data, setData] = useState([])
    const [showHelp, setShowHelp] = useState(false)

    // 查询列表
      const getList = params => {
        request({ ...apis.channelList.getIntroductionList, params: { ...params,channelId: id } }).then(data => {
          console.log(data)
          setData(data)
        })
      }

    // eslint-disable-next-line react-hooks/rules-of-hooks
      useEffect(() => {
        getList({ pageNum: 1, pageSize: 10 });
      }, [])


    const toNewuser = (record) => {
        router.push({
            pathname: '/channel/newCustomer/dataRecord',
            query: {
                channelId: record.channelId,
                targetName: record.targetName,
                targetId: record.targetId,
                targetType: record.targetType,
                buildingId: record.buildingId,
                newCustomers: record.newCustomers,
              },
        });
    }

    const toVisitNum = (record) => {
        router.push({
            pathname: '/channel/newCustomer/visitNum',
        });
    }

    const toPersonNum = (record) => {
        router.push({
            pathname: '/channel/newCustomer/personNum',
        });
    }

    /**
     *
     *
     * @param {*} props
     * @returns
     */
    const columns = [
        {
            title: '类型',
            dataIndex: 'targetType',
            key: 'targetType',
            align: 'center',
        },
        {
            title: '内容',
            dataIndex: 'targetName',
            key: 'targetName',
            align: 'center',

        },
        {
            title: '关联项目',
            dataIndex: 'buildingName',
            key: 'buildingName',
            align: 'center',

        },
        {
            title: '注册用户',
            dataIndex: 'newCustomers',
            key: 'newCustomers',
            align: 'center',
            render: (text, record) => <Navigate onClick={() => toNewuser(record)}>{text}</Navigate>,

        },
        {
            title: '访问人数',
            dataIndex: 'visitPersons',
            key: 'visitPersons',
            align: 'center',
            render: (text, record) => <Navigate onClick={() => toPersonNum(record)}>{text}</Navigate>,

        },
        {
            title: '访问次数',
            dataIndex: 'visitNum',
            key: 'visitNum',
            align: 'center',
            render: (text, record) => <Navigate onClick={() => toVisitNum(record)}>{text}</Navigate>,
        },
    ];


      const changePageNum = pageNumber => {
        getList({ pageNum: pageNumber, pageSize: 10, ...props.form.getFieldsValue() })
      }


    // 提交事件
    const handleSubmit = e => {
        e.preventDefault();
        props.form.validateFields((err, values) => {
            if (!err) {
                console.log(values, 'values')
                getList({ pageNum: 1, pageSize: 10, ...values })
            }
        });
    }

    //   // 重置搜索
    function handleReset() {
        props.form.resetFields();
        setTime('')
        getList({ pageNum: 1, pageSize: 10 })
    }

    const { getFieldDecorator } = props.form
    return (

        <>
            <div>
                <span> 渠道{name}总计引进{customerNum}个注册用户</span>
                <Icon type="question-circle" theme="filled" style={{ fontSize: '25px', color: '#F00', marginLeft: '30px' }} onClick={() => setShowHelp(true)} />
                <Button style={{ float: 'right', zIndex: 1 }} onClick={() => router.go(-1)}>
                    返回
               </Button>
            </div>
            <Modal
                title="相关说明"
                centereds
                visible={showHelp}
                footer={null}
                onCancel={() => setShowHelp(false)}
            // width="700px"
            >
                <p style={{ fontSize: '0.106rem', color: '#333', marginBottom: '8px' }}>新增注册用户：</p>
                <p style={{ fontSize: '0.106rem', color: '#999', marginBottom: '8px' }}>通过关联当前渠道的二维码授权手机号的总人数</p>
                <p style={{ fontSize: '0.106rem', color: '#333', marginBottom: '8px' }}>访问人数：</p>
                <p style={{ fontSize: '0.106rem', color: '#999', marginBottom: '8px' }}>通过关联当前渠道的二维码访问小程序的总人数</p>
                <p style={{ fontSize: '0.106rem', color: '#333', marginBottom: '8px' }}>访问次数：</p>
                <p style={{ fontSize: '0.106rem', color: '#999', marginBottom: '8px' }}>通过关联当前渠道的二维码访问小程序的总次数</p>


            </Modal>
            <Form layout="inline" style={{ marginBottom: '10px' }} onSubmit={e => handleSubmit(e)}>
                <Form.Item>
                    <Radio.Group buttonStyle="solid" value="a">

                        <Radio.Button value="a" onClick={e => handleSubmit(e)}>最近7天</Radio.Button>
                        <Radio.Button value="b" onClick={e => handleSubmit(e)}>最近1月</Radio.Button>
                    </Radio.Group>
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('time', {
                        initialValue: [],
                    })(
                        <RangePicker
                            style={{ paddingLeft: '30px' }}
                            ranges={{
                                Today: [moment(), moment()],
                                'This Month': [moment().startOf('month'), moment().endOf('month')],
                            }}
                        // onChange={(_dates, dateStrings) => onChangetime(_dates, dateStrings)}
                        />,
                    )}
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('build')(
                        <BuildSelect style={{ width: '200px' }} />,
                    )}
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('qrcodetype')(
                        <QrcodeType all visible/>,
                    )}
                </Form.Item>
                <Form.Item>
                    <Button type="primary" htmlType="submit" className={styles.searchBtn}>搜索</Button>
                    <Button style={{ marginLeft: 8 }} onClick={handleReset}>重置</Button>
                </Form.Item>
            </Form>
            <Button type="primary" style={{ float: 'right', marginBottom: '20px', zIndex: 1 }} onClick={() => { }}>导出</Button>
            <Table dataSource={data.records} columns={columns} pagination={false} rowKey={r => r.serialNo} />
            <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
        <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={e => changePageNum(e)} current={data.current}/>
      </div>
        </>
    )
}
const WrappedQrcodelist = Form.create({ name: 'qrcodelist' })(qrcodelist);

export default WrappedQrcodelist
